@@ -3,9 +3,10 @@
 #
 # Copyright (C) AB Strakt 2001, All rights reserved
 #
-# $Id: __init__.py,v 1.2 2001/08/09 13:20:02 martin Exp $
+# $Id: __init__.py,v 1.4 2004/07/22 12:01:25 martin Exp $
 #
 """
 pyOpenSSL - A simple wrapper around the OpenSSL library
 """
-import rand, crypto, SSL
+import rand, crypto, SSL, tsafe
+from version import __version__
